executor

package
v0.0.0-...-2fd8ce2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 15, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Package executor provides the Tool Executor that runs LLM tool calls against Layer 8 service endpoints using internal HTTP requests.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ToolExecutor

type ToolExecutor struct {
	// contains filtered or unexported fields
}

ToolExecutor executes tool calls against Layer 8 service endpoints.

func NewToolExecutor

func NewToolExecutor(prefix string, resources ifs.IResources, schema *schema.Provider, webPort int) *ToolExecutor

NewToolExecutor creates a new ToolExecutor.

func (*ToolExecutor) Execute

func (t *ToolExecutor) Execute(toolName string, input string, bearerToken string) (string, error)

Execute runs a tool call and returns the result as a JSON string.

Jump to