Documentation
¶
Overview ¶
Package l8agent provides the AI Agent shared library for Layer 8 ecosystem projects. Consumer projects call Initialize() with their config to activate all agent services.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Initialize ¶
func Initialize(config AgentConfig, vnic ifs.IVNic) error
Initialize activates all agent services (Chat, Conversations, Prompts). Call this once from the consumer project's activation code.
Types ¶
type AgentConfig ¶
type AgentConfig struct {
Resources ifs.IResources
Prefix string // API prefix (e.g., "/erp/")
ServiceArea byte // Service area for agent services
WebPort int // Web server port for tool executor
DBCreds string // Database credential key
DBName string // Database name
MaskingOverrides MaskingOverrides // Optional: project-specific field overrides
DefaultPrompts []*l8agent.L8AgentPrompt // Optional: built-in prompt templates
}
AgentConfig is the configuration for initializing the agent.
type MaskingOverrides ¶
type MaskingOverrides = masking.OverrideFunc
MaskingOverrides is a function that overrides the default field classification.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package executor provides the Tool Executor that runs LLM tool calls against Layer 8 service endpoints using internal HTTP requests.
|
Package executor provides the Tool Executor that runs LLM tool calls against Layer 8 service endpoints using internal HTTP requests. |
|
Package llm provides the HTTP client for calling the Claude API.
|
Package llm provides the HTTP client for calling the Claude API. |
|
Package masking provides the Data Masking Proxy for protecting sensitive data from being sent to the LLM.
|
Package masking provides the Data Masking Proxy for protecting sensitive data from being sent to the LLM. |
|
Package schema provides the Schema Provider that generates compressed schema metadata for the LLM system prompt from the project's introspector.
|
Package schema provides the Schema Provider that generates compressed schema metadata for the LLM system prompt from the project's introspector. |
|
services
|
|
|
chat
Package chat provides the AgentChat orchestration service.
|
Package chat provides the AgentChat orchestration service. |
|
conversations
Package conversations provides the AgentConversation CRUD service.
|
Package conversations provides the AgentConversation CRUD service. |
|
prompts
Package prompts provides the AgentPrompt CRUD service.
|
Package prompts provides the AgentPrompt CRUD service. |
|
Package tools provides the LLM tool definitions for the AI agent.
|
Package tools provides the LLM tool definitions for the AI agent. |
|
types
|
|
Click to show internal directories.
Click to hide internal directories.